types.kvs

Make it easy to parse & kvs into maps.

Make it easy to parse & kvs into maps.
raw docstring

types.unify

Unify experimental.lite schemas, vector schemas, and kv schemas. (kv schemas are just a simpler syntax for experimental.lite schemas.)

Unify experimental.lite schemas, vector schemas, and kv schemas.
(kv schemas are just a simpler syntax for experimental.lite schemas.)
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries