types.reflectivity


builder-classclj

(builder-class clazz)

Given a class clazz, returns its inner Builder class.

Given a class `clazz`, returns its inner Builder class.
raw docstring

http-requestclj

(http-request request-fn parameters)

Send an OCI request using request-fn and withparameters`. Returns a map with either :data or :error.

Currently 'logs' errors to standard out using pprint; this centralizes error logging for OCI requests in one place to make it easier to modify later.

Send an OCI request using `request-fn` and ` with `parameters`.
Returns a map with either :data or :error.

Currently 'logs' errors to standard out using pprint; this centralizes
error logging for OCI requests in one place to make it easier to modify later.
raw docstring

unary-methodclj

(unary-method clazz method-name-prefix)

Returns the first unary method of a class whose name starts with method-name-prefix.

method-name-prefix may be a symbol, keyword, or string. If it is a symbol or keyword, the leading colon or dot is stripped before comparison.

Returns the first unary method of a class whose name starts with `method-name-prefix`.

`method-name-prefix` may be a symbol, keyword, or string.  If it is a symbol or keyword,
the leading colon or dot is stripped before comparison.
raw docstring

unary-parameter-typeclj

(unary-parameter-type unary-method)

Returns the parameter type of a unary method or nil if not found.

Returns the parameter type of a unary method or nil if not found.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries