clj-oci.clients


authentication-detailsclj

Lazily initialized ConfigFileAuthenticationDetailsProvider instance. Wrapped in delay so that requiring this namespace does not trigger file I/O for ~/.oci/config — only dereferencing does.

Lazily initialized ConfigFileAuthenticationDetailsProvider instance.
Wrapped in delay so that requiring this namespace does not trigger
file I/O for ~/.oci/config — only dereferencing does.
raw docstring

buildcljmacro

(build clazz & args)

OCI has two significant patterns for building API objects. In one pattern, a gratuitous build object is created, zero configuration is performed on the builder object at all, and all configuration is passed as arguments to the build method.

This macro cleans up (DRYs up) that pattern by making object construction look and work like object construction using the new function. For example:

(build FileStorageClient @authentication-details)

OCI has two significant patterns for building API objects.  In one pattern,
a gratuitous build object is created, zero configuration is performed on the
builder object at all, and all configuration is passed as arguments to the build
method.

This macro cleans up (DRYs up) that pattern by making object construction look
and work like object construction using the `new` function.  For example:

(build FileStorageClient @authentication-details)
raw docstring

build*clj

(build* clazz & args)

Implementation function for build macro. Given a class and arguments, generates code that constructs an instance of the class using the builder pattern employed by the OCI SDK.

Implementation function for `build` macro.  Given a class and arguments,
generates code that constructs an instance of the class using the builder pattern
employed by the OCI SDK.
raw docstring

compute-clientclj

Lazily initialized ComputeClient instance. Dereferencing triggers authentication via ~/.oci/config.

Lazily initialized ComputeClient instance.
Dereferencing triggers authentication via `~/.oci/config`.
raw docstring

file-storage-clientclj

Lazily initialized FileStorageClient instance. Dereferencing triggers authentication via ~/.oci/config.

Lazily initialized FileStorageClient instance.
Dereferencing triggers authentication via `~/.oci/config`.
raw docstring

identity-clientclj

Lazily initialized IdentityClient instance. Dereferencing triggers authentication via ~/.oci/config.

Lazily initialized IdentityClient instance.
Dereferencing triggers authentication via `~/.oci/config`.
raw docstring

usageapi-clientclj

Lazily initialized UsageapiClient instance with a custom circuit breaker that excludes HTTP 429 from failure counting. Dereferencing triggers authentication via ~/.oci/config.

Lazily initialized UsageapiClient instance with a custom circuit breaker
that excludes HTTP 429 from failure counting. Dereferencing triggers
authentication via `~/.oci/config`.
raw docstring

with-ociclj

(with-oci client request-type params)

Make an OCI request/response.

Make an OCI request/response.
raw docstring

with-oci-asyncclj

(with-oci-async client request-type params)

Make an asynchronous OCI request/response.

Make an asynchronous OCI request/response.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries